<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>LXQt 마우스 테마 구성</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>사용하려는 커서 테마를 선택합니다(커서를 테스트하려면 미리보기를 가리키십시오). &lt;b&gt;이 변경 후 LXQt 세션을 다시 시작해야 합니다&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="104"/>
        <source>&amp;Install New Theme...</source>
        <translation>새 테마 설치(&amp;I)...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="72"/>
        <source>LXQt session needs restart to view this change.</source>
        <translation>이 변경 사항을 보려면 LXQt 세션을 다시 시작해야 합니다.</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="111"/>
        <source>&amp;Remove Theme</source>
        <translation>테마 제거(&amp;R)</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="65"/>
        <source>Size:</source>
        <translation>크기:</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="231"/>
        <source>XCurTheme error</source>
        <translation>XCurTheme 오류</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="232"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>활성 테마를 제거할 수 없습니다!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>형태</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt에서 커서 테마를 찾을 수 없습니다. 대신 기본 X11 커서 테마가 사용됩니다. LXQt는 다음 디렉터리를 찾았습니다:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>표시...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="63"/>
        <source>Description</source>
        <translation>설명</translation>
    </message>
</context>
</TS>
